clear
close all

cd D:\MATLAB\work\HrZZ_2013_2015\CILS_2014_MATLAB_code

% NMU_A_S_1H_NMR_data_analysis

M = 3; % number of pure components

% NMR spectrometer dependent constants
amin = 0; amax=0.2;
tau = 0.732/0.2; dT=46.4e-6;  
Fs = 2*10775.86;
ppmmax = 9;
   
cd .\1H_NMR_spectra
load X81.txt
T = length(X81);
X(1,:)=X81; 
load X91.txt
X(2,:)=X91; 

[N T]=size(X);
T2 = floor(T/2);
t = 0:T-1;
t = t*dT;

NS = 2;
for n=1:NS
    X(n,:)=X(n,:)-mean(X(n,:));
end

% Conversion from Hz to ppm scale
freq=(1:T2)*0.164427*4;
k=-8.348196399803881e-4; l = 8.500714444911397;
for n=1:length(freq)
        ppmscale(n)=k*freq(n)+l;
end
index = 1:T2;
  
% transforming time domain data to Fourier domain
for n=1:NS
    XF(n,:) = fft(X(n,:))/T;
end

% Mixtures spectra
hh = figure;
figure(hh)
plot(ppmscale(index),abs(XF(1,index)),'k')
title('X1')
amax=max(abs(XF(1,index)));
axis([0 ppmmax amin amax])
xlabel('ppm')
grid


figure
plot(ppmscale(index),abs(XF(2,index)),'k')
title('X2')
amax=max(abs(XF(2,index)));
axis([0 ppmmax amin amax])
xlabel('ppm')
grid


% decompose absolute value first
XFA = abs(XF);

%% the NMU_A algorithm
  norm_type = 2;
  [St,AH_A] = recursive_NMU(XFA',M,norm_type,40);
  SH_A = St';
  clear St;
  

  for n=1:M
        figure
        plot(ppmscale(index),SH_A(n,index),'k')
        amax=max(SH_A(n,index));
        axis([0 ppmmax amin amax])
        title(strcat('SH_A',num2str(n)))
        xlabel('ppm')
    grid
  end

%% the NMU_S algorithm

  norm_type = 2;
  [St,AH_S] = recursive_NMU((XFA.*XFA)',M,norm_type,40);
  SH_S = St';
  clear St;
  SH_S = sqrt(SH_S);
  AH_S = sqrt(AH_S);
  
for n=1:M
    figure
    plot(ppmscale(index),SH_S(n,index),'k')
    amax=max(SH_S(n,index));
    axis([0 ppmmax amin amax])
    title(strcat('SH_S',num2str(n)))
    xlabel('ppm')
  grid
end

% load pure components
load X51.txt
PC(1,:)=X51;
PC(1,:)=PC(1,:)-mean(PC(1,:));
PC(1,:)=fft(PC(1,:))/T;
PC(1,:)=abs(PC(1,:));

load X61.txt
PC(2,:)=X61;
PC(2,:)=PC(2,:)-mean(PC(2,:));
PC(2,:)=fft(PC(2,:))/T;
PC(2,:)=abs(PC(2,:));

load X71.txt
PC(3,:)=X71;
PC(3,:)=PC(3,:)-mean(PC(3,:));
PC(3,:)=fft(PC(3,:))/T;
PC(3,:)=abs(PC(3,:));

% correlation matrix for amplitude algorithm
for i=1:size(SH_A,1)
    for j=1:3
        crf=SH_A(i,index)*transpose(PC(j,index))/norm(SH_A(i,index))/norm(PC(j,index));
        crpcsh_A(i,j)=crf;
    end
end

% correlation matrix for squared amplitude algorithm
for i=1:size(SH_S,1)
    for j=1:3
        crf=SH_S(i,index)*transpose(PC(j,index))/norm(SH_S(i,index))/norm(PC(j,index));
        crpcsh_S(i,j)=crf;
    end
end
