clear
close all

cd D:\MATLAB\work\HrZZ_2013_2015\CILS_2014_MATLAB_code

% NMU_A_S_COSY_NMR_data_analysis

M = 4;   % number of pure components

% device dependent constants    
amin = 0; amax=0.2;
kv = -4.0e-2; lv=16.44;
kh = 2.0178e-2; lh=-4.1797;

% load time domain 2D NMR data
cd .\COSY_NMR_spectra      % time domain 2D NMR data in complex format 
 
load X1
[T1 T2] = size(X1);
load X2;load X3;
    
for n=1:T1/1
     ppmvert(n)=kv*n + lv;
end
for n=1:T2/1
    ppmhorz(n)=kh*n + lh;
end

tmp = fft2(X1)/T1/T2;
tmp = map_2D_NMR_spectra(tmp);

XFA(1,:) = snake(abs(tmp));

% Mixture spectra
figure
contour(ppmhorz,ppmvert,abs(tmp),100)
%colorbar('vert')
xlabel('ppm')
ylabel('ppm')
title('X1')
axis([0.4 9 0.0 9.4])
%grid

tmp = fft2(X2)/T1/T2;
tmp = map_2D_NMR_spectra(tmp);
XFA(2,:) = snake(abs(tmp));

figure
contour(ppmhorz,ppmvert,abs(tmp),100)
xlabel('ppm')
ylabel('ppm')
title('X2')
axis([0.4 9 0.0 9.4])
%grid

tmp = fft2(X3)/T1/T2;
tmp = map_2D_NMR_spectra(tmp);
XFA(3,:) = snake(abs(tmp));

figure
contour(ppmhorz,ppmvert,abs(tmp),100)
xlabel('ppm')
ylabel('ppm')
title('X3')
axis([0.4 9 0.0 9.4])
%grid

%% the NMU_A algorithm

norm_type = 2;
[St,AH_A] = recursive_NMU(XFA',M,norm_type,40);
SH_A = St';
clear St;

%% the NMU_S algorithm
norm_type = 2;
[St,AH_S] = recursive_NMU((XFA.*XFA)',M,norm_type,40);
SH_S = St';
clear St;

SH_S = sqrt(SH_S);
AH_S = sqrt(AH_A);

for n=1:M
    figure
    tmp=isnake(SH_A(n,:),T1,T2);
    contour(ppmhorz,ppmvert,tmp,150)
    xlabel('ppm')
    ylabel('ppm')
    title(strcat('SH_A',num2str(n)))
    axis([0 9.5 0 9.5])
    axis('square')
end

for n=1:M
    figure
    tmp=isnake(SH_S(n,:),T1,T2);
    contour(ppmhorz,ppmvert,tmp,150)
    xlabel('ppm')
    ylabel('ppm')
    title(strcat('SH_S',num2str(n)))
    axis([0 9.5 0 9.5])
    axis('square')
end

% load pure components
load PC1
load PC2
load PC3
load PC4

tmp = abs(fft2(PC1)/T1/T2);
XC(:,1)= snake(map_2D_NMR_spectra(tmp));
tmp = abs(fft2(PC2)/T1/T2);
XC(:,2)= snake(map_2D_NMR_spectra(tmp));
tmp = abs(fft2(PC3)/T1/T2);
XC(:,3)= snake(map_2D_NMR_spectra(tmp));
tmp = abs(fft2(PC4)/T1/T2);
XC(:,4)= snake(map_2D_NMR_spectra(tmp));

% correlation matrix for amplitude algorithm
for i=1:M
    for j=1:M
        crf=SH_A(i,:)*XC(:,j)/norm(SH_A(i,:))/norm(XC(:,j));
        crpcsh_A(i,j)=crf;
    end
end

% correlation matrix for squared amplitude algorithm
for i=1:M
    for j=1:M
        crf=SH_S(i,:)*XC(:,j)/norm(SH_S(i,:))/norm(XC(:,j));
        crpcsh_S(i,j)=crf;
    end
end
